@@ -572,7 +572,7 @@ class IntersphinxRoleResolver(ReferencesResolver):
     default_priority = ReferencesResolver.default_priority - 1
 
     def run(self, **kwargs: Any) -> None:
-        for node in self.document.traverse(pending_xref):
+        for node in self.document.findall(pending_xref):
             if 'intersphinx' not in node:
                 continue
             contnode = cast(nodes.TextElement, node[0].deepcopy())
@@ -595,7 +595,7 @@ class IntersphinxRoleResolver(ReferencesResolver):
 def install_dispatcher(app: Sphinx, docname: str, source: List[str]) -> None:
     """Enable IntersphinxDispatcher.
 
-    .. note:: The installed dispatcher will uninstalled on disabling sphinx_domain
+    .. note:: The installed dispatcher will be uninstalled on disabling sphinx_domain
               automatically.
     """
     dispatcher = IntersphinxDispatcher()
@@ -630,7 +630,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
     app.add_config_value('intersphinx_mapping', {}, True)
     app.add_config_value('intersphinx_cache_limit', 5, False)
     app.add_config_value('intersphinx_timeout', None, False)
-    app.add_config_value('intersphinx_disabled_reftypes', [], True)
+    app.add_config_value('intersphinx_disabled_reftypes', ['std:doc'], True)
     app.connect('config-inited', normalize_intersphinx_mapping, priority=800)
     app.connect('builder-inited', load_mappings)
     app.connect('source-read', install_dispatcher)
